@@ -239,7 +239,11 @@ def _df_to_plotly_heatmap_(
         'marker': {
             'size': scaled_values,
             'color': kwargs.pop('color', DEFAULT_COLOUR),
-            'line': {'width': 0}
+            'line': {
+                'width': kwargs.pop('linewidth', 0),
+                'color': kwargs.pop('linecolour', DEFAULT_COLOUR),
+                'opacity': 1
+            }
         },
         'type': kwargs.pop('type', 'heatmap'),
         'text': text,
@@ -249,11 +253,23 @@ def _df_to_plotly_heatmap_(
 
 def _plotly_c_vs_db_(
     data: Dict[str, Union[Dict[str, pd.DataFrame], pd.DataFrame]],
-    with_groups: bool = True, alpha: float = 1, **kwargs
+    with_groups: bool = True, alpha: float = 1, plot_args: dict = None,
+    **kwargs
 ) -> Tuple[List[Dict[str, Any]], Dict[str, Any]]:
+    dynamic_linecol = False
+    if plot_args is None:
+        plot_args = {}
+    else:
+        dynamic_linecol = plot_args.get('linecolour') is None
     if with_groups:
-        min_ = np.nanmin([np.nanmin(x) for class_data in data.values() for x in class_data.values()])
-        max_ = np.nanmax([np.nanmax(x) for class_data in data.values() for x in class_data.values()])
+        min_ = np.nanmin([
+            np.nanmin(x) for class_data in data.values()
+            for x in class_data.values()
+        ])
+        max_ = np.nanmax([
+            np.nanmax(x) for class_data in data.values()
+            for x in class_data.values()
+        ])
     else:
         min_ = np.nanmin([np.nanmin(x) for x in data.values()])
         max_ = np.nanmax([np.nanmax(x) for x in data.values()])
@@ -263,16 +279,15 @@ def _plotly_c_vs_db_(
             colours = _get_colours_(len(class_data))
             for j, (group, group_data) in enumerate(sorted(class_data.items())):
                 # TODO: add scatter offset per group
+                if dynamic_linecol:
+                    plot_args['linecolour'] = colours[j]
                 pt_form = _df_to_plotly_heatmap_(
                     group_data, type='scatter',
                     color=colours[j],
                     legendgroup=group, extrema=(min_, max_),
                     mode='markers', name=group,
                     opacity=alpha,
-                    # boxpoints='all',
-                    # hoveron='points', pointpos=0,
-                    # boxmode='group', line={'color': 'rgba(0,0,0,0)'},
-                    # fillcolor='rgba(0,0,0,0)'
+                    **plot_args
                 )
                 pt_form['xaxis'] = f'x{i + 1}'
                 pt_form['yaxis'] = f'y{i + 1}'
@@ -284,7 +299,10 @@ def _plotly_c_vs_db_(
                 plots.setdefault(lclass, []).append(pt_form)
         else:
             plots[lclass] = [
-                _df_to_plotly_heatmap_(class_data, type='scatter', extrema=(min_, max_))
+                _df_to_plotly_heatmap_(
+                    class_data, type='scatter', extrema=(min_, max_),
+                    **plot_args
+                )
             ]
     return [plot_data for plot in plots.values() for plot_data in plot], _subplot_layout_(plots, **kwargs)
 
