@@ -463,7 +463,8 @@ class VisParser(Network):
 
     def _prepare_write_(
         self, template: Template = None,
-        force_hierarchical: bool = False
+        force_hierarchical: bool = False,
+        use_molecular_strings: bool = False
     ):
         if self.legend is None:
             raise ValueError(
@@ -511,15 +512,20 @@ class VisParser(Network):
             for attr in ["degree", "betweenness", "closeness"]:
                 nodes[i][attr] = f"{round(nodes[i][attr], ndigits=3)}"
             # adding node_molecule_type based shapes
-            nodes[i]['shape'] = NODE_TYPE_SHAPES.get(nodes[i].get('node_molecule_type'), 'hexagon')
-            if nodes[i].get('node_molecule_type'):
+            nodes[i]['shape'] = NODE_TYPE_SHAPES.get(
+                nodes[i].get('node_molecule_type'), 'hexagon'
+            )
+            if nodes[i].get('node_molecule_type') != 'Lipid':
                 nodes[i]['label'] = nodes[i].get('representation_id', '')
-
-            if nodes[i].get('data_name') is not None:
-                if nodes[i].get('inferred'):
-                    nodes[i]['label'] = nodes[i]['data_name']
+            else:
+                if use_molecular_strings:
+                    mol_string = nodes[i].get('molecular_string')
+                    if mol_string is not None:
+                        nodes[i]['label'] = nodes[i]['molecular_string']
+                    else:
+                        nodes[i]['label'] = nodes[i]['data_name']
                 else:
-                    nodes[i]['label'] = nodes[i]['molecular_string']
+                    nodes[i]['label'] = nodes[i]['data_name']
             # if 'inferred' in nodes[i].keys():
             #     del nodes[i]['inferred']
         # check if physics is enabled
@@ -1018,7 +1024,8 @@ class DynamicVisParser(VisParser):
         force_hierarchical: bool = False,
         groups: Union[List[str], None] = None,
         as_dict: bool = False,
-        group_combinations = None
+        group_combinations = None,
+        use_molecular_strings: bool = False
     ) -> Union[None, dict]:
         """
         Saving DynamicVisParser.network as a html file
@@ -1060,25 +1067,31 @@ class DynamicVisParser(VisParser):
         #    This enables the flexibility to later add other attributes and
         #    save again.
         self._labels_to_ids_()
-        colour_legend = any(["colour" in attr for attr in self._legend_attributes_.keys()])
-        size_legend = any(["size" in attr for attr in self._legend_attributes_.keys()])
+        colour_legend = any(["colour" in attr
+                             for attr in self._legend_attributes_.keys()])
+        size_legend = any(["size" in attr
+                           for attr in self._legend_attributes_.keys()])
         if colour_legend:
             self._consecutive_nodes_("colour")
         if size_legend:
             self._consecutive_nodes_("size")
         # getting all relevant elements for saving
-        network_params = self._prepare_write_(template, force_hierarchical)
+        network_params = self._prepare_write_(template, force_hierarchical,
+                                              use_molecular_strings)
         # adding fixed annotations to nodes and legends
         network_params['nodes'], network_params['edges'] = \
-            self._add_annotations_(network_params['nodes'], network_params['edges'])
+            self._add_annotations_(network_params['nodes'],
+                                   network_params['edges'])
         # ensuring compatibility when no group annotation is provided
         groups = [] if groups is None else groups
         if groups is None:
             group_combinations = []
         elif group_combinations is None:
-            group_combinations = [_tuple_to_string_(comb) for comb in combinations(groups, 2)]
+            group_combinations = [_tuple_to_string_(comb)
+                                  for comb in combinations(groups, 2)]
         else:
-            group_combinations = [_tuple_to_string_(comb) for comb in group_combinations]
+            group_combinations = [_tuple_to_string_(comb)
+                                  for comb in group_combinations]
 
         if as_dict:
             return dict(
